
#pragma once

/*- Error Codes ----------------------------------------------*/

#define FALCON_SUCCESS							(0x0) 
#define FALCON_FORMAT_ERROR						(FALCON_SUCCESS + 0x1)
#define FALCON_CMD_ERROR						(FALCON_SUCCESS + 0x2)
#define FALCON_PARAMETER_RANGE_ERROR			(FALCON_SUCCESS + 0x3)
#define FALCON_TIME_OUT							(FALCON_SUCCESS + 0x4)
#define FALCON_CANNOTOPEN_COMPORT_ERROR			(FALCON_SUCCESS + 0x5)
#define FALCON_CANNOTCLOSE_COMPORT_ERROR		(FALCON_SUCCESS + 0x6)
#define FALCON_CARD_DOESNOT_EXIST_ERROR			(FALCON_SUCCESS + 0x7)
#define FALCON_CARDTYPE_DOESNOT_MATCH_ERROR		(FALCON_SUCCESS + 0x8)
#define FALCON_ERRORCODE_DOESNOT_EXIST_ERROR	(FALCON_SUCCESS + 0x9)


const int MAX_SLOT_VXI_SIZE_CHASSIS = 16;
const int MAX_FALCON_CARD_NAME		= 128;
const int MAX_RETURN_BUFF_SIZE		= 256;

const char M32ID[] = "M32";
const char M64ID[] = "M64";
const char G64ID[] = "G64";

const char CMD_ERROR[] = "CMD Error";
const char FORMAT_ERROR[] = "Format Error";
const char PARAMETER_RANGE_ERROR[] = "Parameter Range Error";

const char COMMAND_BUFF_MAX_LEGNTH = 30;

const int DEFAULT_RESPONDE_TIME_DELAY = 10;
const int M64_RESEt_RESPONDE_TIME_DELAY = 30;
const int M64_MATRIXRELAY_RESPONDE_TIME_DELAY = 5;
const int M32_SELFTEST_TIME_SEC	= 15;
const int M64_SELFTEST_TIME_SEC = 50;
const int G64_SELFTEST_TIME_SEC = 5;

enum SIGNALSTATUS { SIGNALOFF, SIGNALON };

struct Status
{
	int				iCh;
	SIGNALSTATUS	eSignalStatus;
};

typedef void(*OnSignalMonitoring)(Status s[], int iMonitorChannelNum);

struct FalconSeries
{
	int iID;
	char strCardName[MAX_FALCON_CARD_NAME];
};

// Լ
extern "C" __declspec(dllexport) int __stdcall OpenFalcon(char* strComPort);
extern "C" __declspec(dllexport) int __stdcall CloseFalcon();
extern "C" __declspec(dllexport) int __stdcall GetFalconSeries(FalconSeries*& falconseries, int& iNums);
extern "C" __declspec(dllexport) int __stdcall GetFalconErrorInfo(int iErrorCode, char strError[], int iBuffSize);

extern "C" __declspec(dllexport) int __stdcall SelfTestFalcon(int iID, char* strResult, int& iResultLength);
extern "C" __declspec(dllexport) int __stdcall QueryFalconID(int iID, char* strName, int& iNameLength);
extern "C" __declspec(dllexport) int __stdcall ResetFalcon(int iID);

enum ROW_HI_LO { ROWHI, ROWLO };

// M32  Լ
enum M32_DISCHARGE { _10HM, _10OHM, _50OHM, _1KOHM };

const int M32_MIN_ROW_INDEX = 1;
const int M32_MAX_ROW_INDEX = 4;
const int M32_MIN_COL_INDEX = 1;
const int M32_MAX_COL_INDEX = 32;
const int M32_MIN_GP_INDEX	= 1;
const int M32_MAX_GP_INDEX	= 8;
const int M32_MIN_EXTGP_INDEX = 1;
const int M32_MAX_EXTGP_INDEX = 4;
const int M32_MIN_PS_INDEX = 1;
const int M32_MAX_PS_INDEX = 8;

extern "C" __declspec(dllexport) int __stdcall CloseM32RelayMatrix(int iID, int iRow, int iCol);
extern "C" __declspec(dllexport) int __stdcall OpenM32RelayMatrix(int iID, int iRow, int iCol);
extern "C" __declspec(dllexport) int __stdcall CloseM32RowHiLoMatrix(int iID, int iRow, ROW_HI_LO eHiLo);
extern "C" __declspec(dllexport) int __stdcall OpenM32RowHiLoMatrix(int iID, int iRow, ROW_HI_LO eHiLo);
extern "C" __declspec(dllexport) int __stdcall CloseM32GPRelay(int iID, int iGpNum);
extern "C" __declspec(dllexport) int __stdcall OpenM32GPRelay(int iID, int iGpNum);
extern "C" __declspec(dllexport) int __stdcall CloseM32ExtGPRelay(int iID, int iExtGpNum);
extern "C" __declspec(dllexport) int __stdcall OpenM32ExtGPRelay(int iID, int iExtGpNum);
extern "C" __declspec(dllexport) int __stdcall CloseM32PsRelay(int iID, int iPsNum);
extern "C" __declspec(dllexport) int __stdcall OpenM32PsRelay(int iID, int iPsNum);
extern "C" __declspec(dllexport) int __stdcall CloseM32DischargeRelay(int iID, M32_DISCHARGE eDischarge);
extern "C" __declspec(dllexport) int __stdcall OpenM32DischargeRelay(int iID, M32_DISCHARGE eDischarge);
extern "C" __declspec(dllexport) int __stdcall CloseM32PullUpRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall OpenM32PullUpRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall CloseM32PullDownRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall OpenM32PullDownRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall CloseM32TestProbeRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall OpenM32TestProbeRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall CloseM32GndRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall OpenM32GndRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall BeginM32SignalMonitoring(int iID, char* strComPort, double PeriodTime, OnSignalMonitoring callbackfunc);
extern "C" __declspec(dllexport) int __stdcall EndM32SignalMonitoring(int iID);
extern "C" __declspec(dllexport) int __stdcall GetM32SignalMonitoringData(int iID, char* strComPort, int& data);

// M64  Լ
const int M64_MIN_ROW_INDEX = 1;
const int M64_MAX_ROW_INDEX = 4;
const int M64_MIN_COL_INDEX = 1;
const int M64_MAX_COL_INDEX = 64;

extern "C" __declspec(dllexport) int __stdcall CloseM64RelayMatrix(int iID, int iRow, int iCol);
extern "C" __declspec(dllexport) int __stdcall OpenM64RelayMatrix(int iID, int iRow, int iCol);
extern "C" __declspec(dllexport) int __stdcall CloseM64RowHiLoMatrix(int iID, int iRow, ROW_HI_LO eHiLo);
extern "C" __declspec(dllexport) int __stdcall OpenM64RowHiLoMatrix(int iID, int iRow, ROW_HI_LO eHiLo);
extern "C" __declspec(dllexport) int __stdcall CloseM64PullUpRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall OpenM64PullUpRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall CloseM64PullDownRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall OpenM64PullDownRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall CloseM64TestProbeRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall OpenM64TestProbeRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall CloseM64GndRelay(int iID);
extern "C" __declspec(dllexport) int __stdcall OpenM64GndRelay(int iID);

// G64  Լ
const int G64_MIN_GP_INDEX = 1;
const int G64_MAX_GP_INDEX = 64;
const int G64_MIN_EXTGP_INDEX = 1;
const int G64_MAX_EXTGP_INDEX = 8;

extern "C" __declspec(dllexport) int __stdcall CloseG64GPRelay(int iID, int iGpNum);
extern "C" __declspec(dllexport) int __stdcall OpenG64GPRelay(int iID, int iGpNum);
extern "C" __declspec(dllexport) int __stdcall CloseG64ExtGPRelay(int iID, int iExtGpNum);
extern "C" __declspec(dllexport) int __stdcall OpenG64ExtGPRelay(int iID, int iExtGpNum);
extern "C" __declspec(dllexport) int __stdcall BeginG64SignalMonitoring(int iID, char* strComPort, double PeriodTime, OnSignalMonitoring callbackfunc);
extern "C" __declspec(dllexport) int __stdcall EndG64SignalMonitoring(int iID);
extern "C" __declspec(dllexport) int __stdcall GetG64SignalMonitoringData(int iID, char* strComPort, int& data);